Index: /trunk/SophyaPI/PIext/nomhistadapter.h
===================================================================
--- /trunk/SophyaPI/PIext/nomhistadapter.h	(revision 2604)
+++ /trunk/SophyaPI/PIext/nomhistadapter.h	(revision 2605)
@@ -11,10 +11,11 @@
 #include "histos2.h"
 #include "hisprof.h"
+#include "histerr.h"
 #include "ntuple.h"
 #include "xntuple.h"
 
-//-------------------------------------------------------------------------
-// Class Adaptateur d'objet (Pour NamedObjMgr) d'objet Histo / HProf
-//-------------------------------------------------------------------------
+//-----------------------------------------------------------------------------
+// Class Adaptateur d'objet (Pour NamedObjMgr) d'objet Histo / HProf / HistoErr
+//-----------------------------------------------------------------------------
 
 class NOMAdapter_Histo : public NObjMgrAdapter {
@@ -51,5 +52,5 @@
 };
 
-// Class Interface NTuple pour Histo / HProf
+// Class Interface NTuple pour Histo / HProf / HistoErr
 class NTupInt_Histo : public NTupleInterface {
 public:
Index: /trunk/SophyaPI/PIext/pawexecut.cc
===================================================================
--- /trunk/SophyaPI/PIext/pawexecut.cc	(revision 2604)
+++ /trunk/SophyaPI/PIext/pawexecut.cc	(revision 2605)
@@ -9,4 +9,5 @@
 #include "histos2.h"
 #include "hisprof.h"
+#include "histerr.h"
 #include "ntuple.h"
 
@@ -294,7 +295,8 @@
 //ob->DataBlock().Reset(0.);}
 #endif
-else if(typeid(*mobj)==typeid(Histo))   {Histo*   ob=(Histo*)  mobj; ob->Zero();}
-else if(typeid(*mobj)==typeid(HProf))   {HProf*   ob=(HProf*)  mobj; ob->Zero();}
-else if(typeid(*mobj)==typeid(Histo2D)) {Histo2D* ob=(Histo2D*)mobj; ob->Zero();}
+else if(typeid(*mobj)==typeid(Histo))    {Histo* ob=(Histo*)  mobj; ob->Zero();}
+else if(typeid(*mobj)==typeid(HProf))    {HProf* ob=(HProf*)  mobj; ob->Zero();}
+else if(typeid(*mobj)==typeid(HistoErr)) {HistoErr* ob=(HistoErr*)  mobj; ob->Zero();}
+else if(typeid(*mobj)==typeid(Histo2D))  {Histo2D* ob=(Histo2D*)mobj; ob->Zero();}
 else {
   cout<<"PAWExecutor::reset Error , No reset possible on "<<ctyp<<endl;
Index: /trunk/SophyaPI/PIext/piinit.cc
===================================================================
--- /trunk/SophyaPI/PIext/piinit.cc	(revision 2604)
+++ /trunk/SophyaPI/PIext/piinit.cc	(revision 2605)
@@ -42,4 +42,5 @@
   serv->RegisterClass(new Histo, new NOMAdapter_Histo );
   serv->RegisterClass(new HProf, new NOMAdapter_Histo );
+  serv->RegisterClass(new HistoErr, new NOMAdapter_Histo );
   serv->RegisterClass(new Histo2D, new NOMAdapter_Histo2D );
   serv->RegisterClass(new NTuple, new NOMAdapter_NTuple );
Index: /trunk/SophyaPI/PIext/servnobjm.cc
===================================================================
--- /trunk/SophyaPI/PIext/servnobjm.cc	(revision 2604)
+++ /trunk/SophyaPI/PIext/servnobjm.cc	(revision 2605)
@@ -1390,4 +1390,6 @@
   case ClassId_HProf : 
     return("HProf");
+  case ClassId_HistoErr : 
+    return("HistoErr");
   case ClassId_NTuple : 
     return("NTuple");

Index: /trunk/SophyaPI/PIext/nomhistadapter.cc
===================================================================
--- /trunk/SophyaPI/PIext/nomhistadapter.cc	(revision 2604)
+++ /trunk/SophyaPI/PIext/nomhistadapter.cc	(revision 2605)
@@ -17,7 +17,7 @@
 #endif
 
 //-------------------------------------------------------------------------
 // Class Adaptateur d'objet (Pour NamedObjMgr) d'objet Histo / HProf
 //-------------------------------------------------------------------------
 
 /* --Methode-- */
@@ -45,5 +45,8 @@
 {
 HProf * hp = dynamic_cast<HProf *>(mHis);
-if(hp) return("HProf "); else return("Histo ");
+HistoErr * herr = dynamic_cast<HistoErr *>(mHis);
+if(hp) return("HProf ");
+else if(herr) return("HistoErr ");
+else return("Histo ");
 }
 
@@ -78,6 +81,8 @@
 mHis->UpdateHisto();  // pour le cas ou c'est un HProf
 HProf * hp = dynamic_cast<HProf *>(mHis);
-if(hp==NULL) return( new Histo(*mHis) );
-return( new HProf(*hp) );
+HistoErr * herr = dynamic_cast<HistoErr *>(mHis);
+if(hp) return( new HProf(*hp) );
+else if(herr) return( new HistoErr(*herr) );
+else return( new Histo(*mHis) );
 }
 
@@ -17,7 +17,7 @@
 #endif
 
-//-------------------------------------------------------------------------
-// Class Adaptateur d'objet (Pour NamedObjMgr) d'objet Histo / HProf
-//-------------------------------------------------------------------------
+//-----------------------------------------------------------------------------
+// Class Adaptateur d'objet (Pour NamedObjMgr) d'objet Histo / HProf / HistoErr
+//-----------------------------------------------------------------------------
 
 /* --Methode-- */